#! /usr/bin/python



__author__ = 'Predrag Pejovic'
__license__ = 'GPLv3'
__date__ = '2021-11-27'



from pylab import *
from oscusb3 import *
import usbtmc
import time



t1 = time.time()



amplitudes = arange(0.5, 10.5, 0.5) * 2
displayset = array([0.5, 2.5, 5, 7.5, 10]) * 2

Tstring = 'T1'

R = 50
f = 4000.0

dt = 1.0 / f / 2500
scale = 1.0 / f / 10

ch1scale = '2'
ch2scale = '5'

tsleep = 0.5



################################################################################
#
# generator
#
gen = usbtmc.Instrument(0x0957, 0x0407)
gen.write('output off')
gen.write('function sinusoid')
gen.write('voltage:amplitude 20e-3')
gen.write('voltage:offset 0')
gen.write('output:load 9.9e37')
gen.write('frequency ' + str(f))
gen.write('output on')
#
def genamp(amplitude):
    gen.write('voltage:amplitude ' + str(amplitude))
#
################################################################################



################################################################################
#
o = Oscilloscope(shy = True)
#
o.write('*rst')
#
o.write('select:ch1 on')
o.write('ch1:probe 1')
o.write('ch1:scale ' + ch1scale)
o.write('ch1:coupling dc')
o.write('ch1:bandwidth on')
#
o.write('select:ch2 on')
o.write('ch2:probe 1')
o.write('ch2:scale ' + ch2scale)
o.write('ch2:coupling dc')
o.write('ch2:bandwidth on')
#
o.write('horizontal:scale ' + str(scale))
o.write('horizontal:position 0')
#
o.write('trigger:main:edge:source ext')
o.write('trigger:main:level 0.7')
#
o.waituntilready()
#
################################################################################



close('all')
rc('text', usetex = True)
rc('font', family = 'serif')
rc('font', size = 12)
rcParams['text.latex.preamble']=[r'\usepackage{amsmath}']

n = len(amplitudes)

maxil = empty(n)
minil = empty(n)
maxll = empty(n)
minll = empty(n)
Pmag = empty(n)

for i in range(n):
    #
    print()
    print('Vm = {:4.1f}'.format(amplitudes[i] / 2.0))
    #
    genamp(amplitudes[i])
    #
    time.sleep(tsleep)
    #
    o.stop()
    #
    print('getting ch1 . . .')
    vi = o.getsamples(1)
    il = vi / R
    il *= 1e3
    #
    print('getting ch2 . . .')
    vl = o.getsamples(2)
    vl -= mean(vl)
    ll = dt * cumsum(vl)
    ll -= mean(ll)
    ll *= 1e3
    #
    o.run()
    #
    maxil[i] = max(il)
    minil[i] = min(il)
    minll[i] = min(ll)
    maxll[i] = max(ll)
    #
    Pmag[i] = mean(il * vl)
    #
    if amplitudes[i] in displayset:
        figure(1)
        plot(il, ll)
    #
    figure(2)
    clf()
    plot(il, ll)
    xlabel(r'$i \; [\text{mA}]$')
    xlim(-100, 100)
    ylabel(r'$\lambda \; [\text{mWb}]$')
    ylim(-0.5, 0.5)
    title(Tstring + r', $V_m = {:4.1f}'.format(amplitudes[i] / 2.0) + 
    r' \; \text{V}$' + r', $f = {:.1f}'.format(f) + r' \, \text{Hz}$')
    grid()
    # savefig('h{:02d}.pdf'.format(i + 1))
    savefig('h{:02d}.png'.format(i + 1))

gen.write('output off')

figure(1)
xlabel(r'$i \; [\text{mA}]$')
xlim(-100, 100)
ylabel(r'$\lambda \; [\text{mWb}]$')
ylim(-0.5, 0.5)
title(r'Magnetizing Curves, ' + Tstring + 
r', $f = {:.1f}'.format(f) + r' \, \text{Hz}$')
grid()
# savefig('hysteresis.pdf')
savefig('hysteresis.png')

ilp = concatenate((minil[-1 : : -1], maxil))
llp = concatenate((minll[-1 : : -1], maxll))
figure(3)
plot(ilp, llp, 'b')
plot(ilp, llp, 'b.')
xlabel(r'$i \; [\text{mA}]$')
xlim(-100, 100)
ylabel(r'$\lambda \; [\text{mWb}]$')
ylim(-0.5, 0.5)
title('Normal Magnetizing Curve, ' + Tstring + 
r', $f = {:.1f}'.format(f) + r' \, \text{Hz}$')
grid()
# savefig('single-curve.pdf')
savefig('single-curve.png')

lmax = (maxll - minll) / 2
imax = (maxil - minil) / 2
#
figure(4)
plot(lmax, Pmag, 'b')
plot(lmax, Pmag, 'b.')
xlabel(r'$\lambda_{max} \; [\text{mWb}]$')
#xlim(0, 0.5)
ylabel(r'$P_{core} \; [\text{mW}]$')
#ylim(0, 5)
title('Core Loss, ' + Tstring + r', $f = {:.1f}'.format(f) + r' \, \text{Hz}$')
grid()
# savefig('core-loss-lambda.pdf')
savefig('core-loss-lambda.png')
#
figure(5)
plot(imax, Pmag, 'b')
plot(imax, Pmag, 'b.')
xlabel(r'$i_{max} \; [\text{mA}]$')
#xlim(0, 100)
ylabel(r'$P_{core} \; [\text{mW}]$')
#ylim(0, 5)
title('Core Loss, ' + Tstring + r', $f = {:.1f}'.format(f) + r' \, \text{Hz}$')
grid()
# savefig('core-loss-current.pdf')
savefig('core-loss-current.png')

np.save('Pmag.npy', Pmag)
np.save('i_max.npy', imax)
np.save('lambda_max.npy', lmax)

t2 = time.time()

print()
print 'completed in {:.2f} s'.format(t2 - t1)
print

