#! /usr/bin/python



__author__ = 'Predrag Pejovic'
__license__ = 'GPLv3'
__date__ = '2021-11-27'



from pylab import *
from oscusb3 import *
import usbtmc
import time



t1 = time.time()

amplitudes = arange(1, 21)
displayset = [1, 5, 10, 15, 20]

R = 50
f = 100.0

scale = 2.5 / f / 10.0

ch1scale = '2'
ch2scale = '0.005'

tsleep = 0.5
taverage = 10 * scale * 128


################################################################################
#
# generator
#
gen = usbtmc.Instrument(0x0957, 0x0407)
gen.write('output off')
gen.write('function sinusoid')
gen.write('voltage:amplitude 20e-3')
gen.write('voltage:offset 0')
gen.write('output:load 9.9e37')
gen.write('frequency ' + str(f))
gen.write('output on')
#
def genamp(amplitude):
    gen.write('voltage:amplitude ' + str(amplitude))
#
################################################################################



################################################################################
#
o = Oscilloscope(shy = True)
#
o.write('*rst')
#
o.waituntilready()
#
o.write('select:ch1 on')
o.write('ch1:probe 1')
o.write('ch1:scale ' + ch1scale)
o.write('ch1:coupling dc')
o.write('ch1:bandwidth on')
#
o.write('select:ch2 on')
o.write('ch2:probe 1')
o.write('ch2:scale ' + ch2scale)
o.write('ch2:coupling dc')
o.write('ch2:bandwidth on')
#
o.write('trigger:main:edge:source ext')
o.write('trigger:main:level 0.7')
#
o.write('display:format xy')
#
o.waituntilready()
#
o.write('horizontal:scale ' + str(scale))
o.write('horizontal:position 0')
#
o.waituntilready()
#
################################################################################



print()

close('all')

n = len(amplitudes)

for i in range(n):
    #
    print('Vm = {:4.1f}'.format(amplitudes[i] / 2.0))
    #
    genamp(amplitudes[i])
    #
    time.sleep(tsleep)
    #
    o.write('acquire:mode average; numavg 128')
    time.sleep(taverage)
    #
    o.getjpg('xy_{:02d}'.format(i + 1), ts = False)
    #
    o.write('acquire:mode sample')

gen.write('output off')



t2 = time.time()

print()
print 'completed in {:.2f} s'.format(t2 - t1)
print

