#! /usr/bin/python



__author__ = 'Predrag Pejovic'
__license__ = 'GPLv3'
__date__ = '2021-11-27'



from pylab import *
from oscusb3 import *
import usbtmc
import time



t1 = time.time()

tsleep = 1



o1 = arange(0, 10, 0.5)
o2 = arange(9.5, -10, -0.5)
o3 = arange(-9.5, 0.5, 0.5)
offsets = concatenate((o1, o2, o3, o1, o2, o3))

R = 50
f = 4000.0
w = 2 * pi * f
#
scale = 50e-6



################################################################################
#
# generator
#
gen = usbtmc.Instrument(0x0957, 0x0407)
gen.write('output off')
gen.write('function sinusoid')
gen.write('voltage:amplitude 1')
gen.write('voltage:offset 0')
gen.write('output:load 9.9e37')
gen.write('frequency ' + str(f))
gen.write('output on')
#
################################################################################



################################################################################
#
o = Oscilloscope(shy = True)
#
o.write('*rst')
#
o.write('select:ch1 on')
o.write('ch1:probe 1')
o.write('ch1:scale 2')
o.write('ch1:coupling dc')
o.write('ch1:bandwidth on')
#
o.write('select:ch2 on')
o.write('ch2:probe 1')
o.write('ch2:scale 0.2')
o.write('ch2:coupling ac')
o.write('ch2:bandwidth on')
#
o.write('horizontal:scale ' + str(scale))
o.write('horizontal:position 0')
#
o.write('trigger:main:edge:source ext')
o.write('trigger:main:level 0.7')
#
o.waituntilready()
#
################################################################################



print()

close('all')
rc('text', usetex = True)
rc('font', family = 'serif')
rc('font', size = 12)
rcParams['text.latex.preamble']=[r'\usepackage{amsmath}']

n = len(offsets)

I1 = empty(n)
I1rms = empty(n)
V2rms = empty(n)
M = empty(n)

for i in range(n):
    #
    gen.write('voltage:offset ' + str(offsets[i]))
    #
    o.write('ch1:coupling dc')
    o.write('ch1:scale 2')
    #
    time.sleep(tsleep)
    #
    o.write('measure:immed:type mean; source ch1')
    I1[i] = float(o.getvalue()) / R
    #
    o.write('ch1:coupling ac')
    o.write('ch1:scale 0.1')
    #
    time.sleep(tsleep)
    #
    o.write('measure:immed:type rms; source ch1')
    I1rms[i] = float(o.getvalue()) / R
    #
    o.write('measure:immed:type rms; source ch2')
    V2rms[i] = float(o.getvalue())
    #
    M[i] = V2rms[i] / (w * I1rms[i])
    #
    print('I_bias = {:5.1f} mA, M = {:4.1f} mH'.format(I1[i] * 1e3, M[i] * 1e3))

gen.write('output off')
o.write('ch1:coupling dc')
o.write('ch2:coupling dc')



figure(1)
plot(I1 * 1e3, M * 1e3, 'b')
plot(I1 * 1e3, M * 1e3, 'b.')
xlim(-100, 100)
# ylim(0, 20)
xlabel(r'$I_{bias} \, [\text{mA}]$')
ylabel(r'$M \, [\text{mH}]$')
grid()
# savefig('MofIbias-2.pdf')
savefig('MofIbias-2.png')



np.save('I1-2.npy', I1)
np.save('I1rms-2.npy', I1rms)
np.save('V2rms-2.npy', V2rms)
np.save('M-2.npy', M)



t2 = time.time()
deltat = t2 - t1
m = int(deltat) / 60
s = deltat - 60 * m

print()
print 'completed in {:d} minutes {:.2f} seconds'.format(m, s)
print

